@@ -23,7 +23,10 @@ SOFTWARE.
 
 '''
 import hashlib
+from inspect import trace
 import os
+from traceback import StackSummary
+import traceback
 import typing
 from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, Set, Union
@@ -48,13 +51,16 @@ class BuildTarget(object):
     BT_COLOR: str = 'cyan'
     BT_LABEL: str = 'FIXME'
 
-    #           YYYYMMDDhhmm
-    CACHE_VER: int = 202101160312
+    #                YYYYMMDDhhmm
+    CACHE_VER: int = 202205141832
 
     CHECK_MTIMES: bool = True
     CHECK_HASHES: bool = True
 
     def __init__(self, targets: Union[List[str], str]=[], files: List[str]=[], dependencies: List[str]=[], provides: List[str]=[], name: str='') -> None:
+        self.id: int = 0
+        self.instantiated_at: StackSummary = traceback.extract_stack() # Instantiation
+        self.added_at: Optional[StackSummary] = None
         self._all_provides: List[str] = targets if isinstance(targets, list) else [targets]+provides
         self.name: str = ''
         try:
@@ -386,6 +392,14 @@ class BuildTarget(object):
         p.parent.mkdir(exist_ok=True)
         p.touch(exist_ok=True)
 
+    def _dumpStacks(self) -> None:
+        with log.info('Created:'):
+            [log.info(sl) for sl in traceback.format_list(self.instantiated_at)]
+        if self.added_at:
+            with log.info('Added:'):
+                [log.info(sl) for sl in traceback.format_list(self.added_at)]
+
+
 class SingleBuildTarget(BuildTarget):
     def __init__(self, target: str, files: List[str] = [], dependencies: List[str] = [], provides: List[str] = [], name: str = '') -> None:
         self.target=target
