@@ -1,5 +1,5 @@
 '''
-BLURB GOES HERE.
+Base enumwriter.
 
 Copyright (c) 2015 - 2022 Rob "N3X15" Nelson <nexisentertainment@gmail.com>
 
@@ -20,29 +20,19 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
-
 '''
-class EnumWriter(object):
-    def __init__(self):
+
+from typing import TextIO
+
+from buildtools.maestro.enumwriters.types import EnumDefinition
+
+
+class EnumWriter:
+    def __init__(self) -> None:
         self.parent = None
 
-    def get_config(self):
+    def get_config(self) -> dict:
         return {}
 
-    def _get_value_for(self, vpak):
-        if isinstance(vpak, dict):
-            return vpak['value']
-        else:
-            return vpak
-
-    def _get_meaning_for(self, vpak):
-        return self._get_for(vpak, 'meaning')
-
-    def _get_for(self, vpak, key, default=''):
-        if isinstance(vpak, dict):
-            return vpak.get(key, default)
-        else:
-            return default
-
-    def write(self, w, definition):
+    def write(self, w: TextIO, ed: EnumDefinition) -> None:
         return
